==> manage-3.1.0-44.jar: management/sqls/营收/报表管理/统计类/预售收入汇总表/getOtherCharge.sql <==
select
	Convert(decimal(18,2),sum(rcwx)) rcwx,
	Convert(decimal(18,2),sum(icc)) icc,
	Convert(decimal(18,2),sum(bjhz)) bjhz,
	Convert(decimal(18,2),sum(dcf)) dcf,
	Convert(decimal(18,2),sum(zbf)) zbf,
	Convert(decimal(18,2),sum(rcwx+icc+bjhz+dcf)) myxj,
	Convert(decimal(18,2),sum(llj)) llj,
	Convert(decimal(18,2),sum(sybjq)) sybjq,
	Convert(decimal(18,2),sum(ycicc)) ycicc,
	Convert(decimal(18,2),sum(llj+sybjq+ycicc)) fmyxj,

	Convert(decimal(18,2),sum(zrcwx)) zrcwx,
	Convert(decimal(18,2),sum(zicc)) zicc,
	Convert(decimal(18,2),sum(zbjhz)) zbjhz,
	Convert(decimal(18,2),sum(zdcf)) zdcf,
	Convert(decimal(18,2),sum(zzbf)) zzbf,
	Convert(decimal(18,2),sum(zrcwx+zicc+zbjhz+zdcf)) zmyxj,
	Convert(decimal(18,2),sum(zllj)) zllj,
	Convert(decimal(18,2),sum(zsybjq)) zsybjq,
	Convert(decimal(18,2),sum(zycicc)) zycicc,
	Convert(decimal(18,2),sum(zllj+zsybjq+zycicc)) zfmyxj
from(
select
	sum(case when u.f_user_type='民用' and f_brand_spec='日常维修' then f_money end) rcwx,
	sum(case when u.f_user_type='民用' and f_brand_spec='IC卡' then f_money end) icc,
	sum(case when u.f_user_type='民用' and f_brand_spec='报警器盒子' then f_money end) bjhz,
	sum(case when u.f_user_type='民用' and f_brand_spec='电磁阀' then f_money end) dcf,
	sum(case when u.f_user_type='民用' and f_brand_spec='自闭阀' then f_money end) zbf,
	sum(case when u.f_user_type='非民用' and f_brand_spec='流量计' then f_money end) llj,
	sum(case when u.f_user_type='非民用' and f_brand_spec='商业报警器' then f_money end) sybjq,
	sum(case when u.f_user_type='非民用' and f_brand_spec='远传IC卡智能商用燃气表' then f_money end) ycicc,
	0 zrcwx,
	0 zicc,
	0 zbjhz,
	0 zdcf,
	0 zzbf,
	0 zllj,
	0 zsybjq,
	0 zycicc
from (select id,f_userinfo_id from t_othercharge where f_state='有效' and f_operate_date>='{startDate}' and f_operate_date<='{endDate}' AND {f_orgid}) o
left join (
	select f_othercharge_id,f_brand_spec,f_number*f_unitprice f_money from  t_othercharge_detail
) d on o.id=d.f_othercharge_id
left join t_userinfo u on o.f_userinfo_id=u.f_userinfo_id
union all
select
	0 rcwx,
	0 icc,
	0 bjhz,
	0 dcf,
	0 zbf,
	0 llj,
	0 sybjq,
	0 ycicc,
	sum(case when u.f_user_type='民用' and f_brand_spec='日常维修' then f_money end) zrcwx,
	sum(case when u.f_user_type='民用' and f_brand_spec='IC卡' then f_money end) zicc,
	sum(case when u.f_user_type='民用' and f_brand_spec='报警器盒子' then f_money end) zbjhz,
	sum(case when u.f_user_type='民用' and f_brand_spec='电磁阀' then f_money end) zdcf,
	sum(case when u.f_user_type='民用' and f_brand_spec='自闭阀' then f_money end) zzbf,
	sum(case when u.f_user_type='非民用' and f_brand_spec='流量计' then f_money end) zllj,
	sum(case when u.f_user_type='非民用' and f_brand_spec='商业报警器' then f_money end) zsybjq,
	sum(case when u.f_user_type='非民用' and f_brand_spec='远传IC卡智能商用燃气表' then f_money end) zycicc
from (select id,f_userinfo_id from t_othercharge where f_state='有效' and DATEPART(YY, f_operate_date) = DATEPART(YY, '{endDate}') AND {f_orgid}) o
left join (
	select f_othercharge_id,f_brand_spec,f_number*f_unitprice f_money from  t_othercharge_detail
) d on o.id=d.f_othercharge_id
left join t_userinfo u on o.f_userinfo_id=u.f_userinfo_id
) t

==> manage-3.1.0-46.jar: management/sqls/营收/报表管理/统计类/预售收入汇总表/getOtherCharge.sql <==
select
	Convert(decimal(18,2),sum(rcwx)) rcwx,
	Convert(decimal(18,2),sum(icc)) icc,
	Convert(decimal(18,2),sum(bjhz)) bjhz,
	Convert(decimal(18,2),sum(dcf)) dcf,
	Convert(decimal(18,2),sum(zbf)) zbf,
	Convert(decimal(18,2),sum(rcwx+icc+bjhz+dcf)) myxj,
	Convert(decimal(18,2),sum(llj)) llj,
	Convert(decimal(18,2),sum(sybjq)) sybjq,
	Convert(decimal(18,2),sum(ycicc)) ycicc,
	Convert(decimal(18,2),sum(llj+sybjq+ycicc)) fmyxj,

	Convert(decimal(18,2),sum(zrcwx)) zrcwx,
	Convert(decimal(18,2),sum(zicc)) zicc,
	Convert(decimal(18,2),sum(zbjhz)) zbjhz,
	Convert(decimal(18,2),sum(zdcf)) zdcf,
	Convert(decimal(18,2),sum(zzbf)) zzbf,
	Convert(decimal(18,2),sum(zrcwx+zicc+zbjhz+zdcf)) zmyxj,
	Convert(decimal(18,2),sum(zllj)) zllj,
	Convert(decimal(18,2),sum(zsybjq)) zsybjq,
	Convert(decimal(18,2),sum(zycicc)) zycicc,
	Convert(decimal(18,2),sum(zllj+zsybjq+zycicc)) zfmyxj
from(
select
	sum(case when u.f_user_type='民用' and f_brand_spec='日常维修' then f_money end) rcwx,
	sum(case when u.f_user_type='民用' and f_brand_spec='IC卡' then f_money end) icc,
	sum(case when u.f_user_type='民用' and f_brand_spec='报警器盒子' then f_money end) bjhz,
	sum(case when u.f_user_type='民用' and f_brand_spec='电磁阀' then f_money end) dcf,
	sum(case when u.f_user_type='民用' and f_brand_spec='自闭阀' then f_money end) zbf,
	sum(case when u.f_user_type='非民用' and f_brand_spec='流量计' then f_money end) llj,
	sum(case when u.f_user_type='非民用' and f_brand_spec='商业报警器' then f_money end) sybjq,
	sum(case when u.f_user_type='非民用' and f_brand_spec='远传IC卡智能商用燃气表' then f_money end) ycicc,
	0 zrcwx,
	0 zicc,
	0 zbjhz,
	0 zdcf,
	0 zzbf,
	0 zllj,
	0 zsybjq,
	0 zycicc
from (select id,f_userinfo_id from t_othercharge where f_state='有效' and f_operate_date>='{startDate}' and f_operate_date<='{endDate}' AND {f_orgid}) o
left join (
	select f_othercharge_id,f_brand_spec,f_number*f_unitprice f_money from  t_othercharge_detail
) d on o.id=d.f_othercharge_id
left join (select f_user_type,f_userinfo_id from t_userfiles where f_table_state='正常') u on o.f_userinfo_id=u.f_userinfo_id
union all
select
	0 rcwx,
	0 icc,
	0 bjhz,
	0 dcf,
	0 zbf,
	0 llj,
	0 sybjq,
	0 ycicc,
	sum(case when u.f_user_type='民用' and f_brand_spec='日常维修' then f_money end) zrcwx,
	sum(case when u.f_user_type='民用' and f_brand_spec='IC卡' then f_money end) zicc,
	sum(case when u.f_user_type='民用' and f_brand_spec='报警器盒子' then f_money end) zbjhz,
	sum(case when u.f_user_type='民用' and f_brand_spec='电磁阀' then f_money end) zdcf,
	sum(case when u.f_user_type='民用' and f_brand_spec='自闭阀' then f_money end) zzbf,
	sum(case when u.f_user_type='非民用' and f_brand_spec='流量计' then f_money end) zllj,
	sum(case when u.f_user_type='非民用' and f_brand_spec='商业报警器' then f_money end) zsybjq,
	sum(case when u.f_user_type='非民用' and f_brand_spec='远传IC卡智能商用燃气表' then f_money end) zycicc
from (select id,f_userinfo_id from t_othercharge where f_state='有效' and DATEPART(YY, f_operate_date) = DATEPART(YY, '{endDate}') AND {f_orgid}) o
left join (
	select f_othercharge_id,f_brand_spec,f_number*f_unitprice f_money from  t_othercharge_detail
) d on o.id=d.f_othercharge_id
left join (select f_user_type,f_userinfo_id from t_userfiles where f_table_state='正常') u on o.f_userinfo_id=u.f_userinfo_id
) t
